#!/bin/sh
#
#   guess-helper.sh
#   Copyright (C) 2004 Tobias Grimm <tg@e-tobi.net>
# 
#   $Id: guess-helper.sh,v 1.2 2004/02/29 23:00:33 bistr-o-math Exp $
# 

# prepare to use gettext, if installed:
if [ -x /usr/bin/gettext ]
then
  export TEXTDOMAIN=guess-helper
  echo="gettext -s"
else
  echo="echo"
fi

# clear console window and print header line
ClearScreen ()
{
  clear
  echo
  echo guess-helper
  echo ------------
  echo
}

# AskQuestion "Do you like Debian?" Y n  > Do you like Debian? [Y/n]
AskQuestion ()
{
  if [ -x /usr/bin/gettext ]
  then
    question=`gettext "$1"`
  else
    question=$1    
  fi

  shift

  answers=""
  for answer in $*
  do
    if [ -x /usr/bin/gettext ]
    then
      answer=`gettext "$answer"`
    fi
    answers="$answers $answer"
  done

  choices=""  
  for answer in $answers
  do
    if [ "$choices" = "" ]
    then
      choices="[$answer"
    else
      choices="$choices/$answer"
    fi
  done
  choices="$choices]"

  answers=`$echo $answers | tr [:lower:] [:upper:]`
  
  result=0
  
  while [ $result -eq 0 ]
  do
    echo -n "$question" "$choices "
    read input
      
    if [ "$input" = "" ]
    then
      result=1
    else
      input=`echo $input | tr [:lower:] [:upper:]`
      i=1
      for answer in $answers
      do
        if [ "$answer" = "$input" ]
	then
	  result=$i
	fi
	i=`expr $i + 1`
      done
    fi
  done

  return $result
}

# Translate and print text lines
EchoTextLines ()
{
  textLines=""

  while [ "$1" ]
  do
    textLines="$textLines$1"
    shift
  done

  $echo -ne "$textLines"
}

# show next wakeup time settings and ask for reboot
ShowBiosSettings ()
{
  ClearScreen
  EchoTextLines \
    "On the next reboot, please enter the BIOS settings and change\n" \
    "the wakeup time settings to the following values:\n"
  echo
  $echo -n "Day       = " ; echo "$1"
  $echo -n "Hour      = " ; echo "$2"
  $echo -n "Minute    = " ; echo "$3"
  $echo -n "Second    = " ; echo "$4"
  if [ $5 -eq 1 ]
  then
    $echo "Enabled   = Yes"
  else
    $echo "Enabled   = No"
  fi
  echo
  AskQuestion "Restart or Abort?" "A" "r" 
  if [ $? -eq 2 ]
  then
    echo 
    EchoTextLines \
      "After changing the wakeup time in the BIOS settings and rebooting the PC,\n"\
      "please run this script again (PC will reboot in 10 seconds...)\n"
    sleep 10
    shutdown -r now
    exit 0
  else
    echo 
    $echo "Script aborted !!!"
    echo
    exit 0
  fi
}

step0file=guess_helper.conf
step1file=31.23.59.59+
step2file=11.12.13.14+
step3file=01.00.00.00+
step4file=01.00.00.00-

if [ ! -f ~/guess-directisa/$step0file ]
then
  ClearScreen
  EchoTextLines \
    "The aim of this script is to help you figuring out the addresses of the\n"\
    "wakeup time in the NVRAM of your PC. You will have to do this only,\n"\
    "if your mainboard couldn't be detected by nvram-wakeup.\n"\
    "\n"\
    "In several steps it will be necessary to reboot the PC, change the\n"\
    "wakeup time in the BIOS and then run guess_helper.sh again.\n"\
    "\n"\
    "This script will create several temporary files and a config file for\n"\
    "nvram-wakeup. This will be done in your home directory.\n"
  echo
  AskQuestion "Continue with the first step of the nvram-wakeup address detection?" "N" "y"
  [ $? -eq 1 ] && exit
  ClearScreen
  mkdir ~/guess-directisa
  $echo "Please select the chipset of your Board -"
  AskQuestion  "(U)nknown, (I)NTEL, (V)IA686A or (D)S1685:" "U" "i" "v" "d"
  case $? in
    2) 
      echo "catOptions=\"INTEL\"" >~/guess-directisa/$step0file 
      ;;
    3) 
      echo "catOptions=\"VIA686A\"" >~/guess-directisa/$step0file  
      ;;
    4) 
      echo "catOptions=\"DS1685\"" >~/guess-directisa/$step0file  
      ;;
    *)
      echo "catOptions=\"\"" >~/guess-directisa/$step0file
      ;;
  esac
  ShowBiosSettings 31 23 59 59 1 
else
  . ~/guess-directisa/$step0file
  if [ ! -f ~/guess-directisa/$step1file ]
  then
    [ -c /dev/nvram ] && mkdir ~/guess-nvram-module
    cat_nvram $catOptions > ~/guess-directisa/$step1file 2>~/guess-directisa/cat_nvram.log
    [ -c /dev/nvram ] && cat /dev/nvram > ~/guess-nvram-module/$step1file 2>~/guess-nvram-module/cat.log
    ShowBiosSettings 11 12 13 14 1
  else    
    if [ ! -f ~/guess-directisa/$step2file ]
    then
      cat_nvram $catOptions > ~/guess-directisa/$step2file 2>>~/guess-directisa/cat_nvram.log
      [ -c /dev/nvram ] && cat /dev/nvram > ~/guess-nvram-module/$step2file 2>>~/guess-nvram-module/cat.log
      ShowBiosSettings 01 00 00 00 1
    else    
      if [ ! -f ~/guess-directisa/$step3file ]
      then
        cat_nvram $catOptions > ~/guess-directisa/$step3file 2>>~/guess-directisa/cat_nvram.log
        [ -c /dev/nvram ] && cat /dev/nvram > ~/guess-nvram-module/$step3file 2>>~/guess-nvram-module/cat.log
        ShowBiosSettings 01 00 00 00 0
      else
        ClearScreen
        cat_nvram $catOptions > ~/guess-directisa/$step4file 2>>~/guess-directisa/cat_nvram.log
        [ -c /dev/nvram ] && cat /dev/nvram > ~/guess-nvram-module/$step4file 2>>~/guess-nvram-module/cat.log
	
	cd ~/guess-directisa
	guess > nvram-wakeup.conf 2> guess-error.log
	cd ~/guess-nvram-module
	guess > nvram-wakeup.conf 2> guess-error.log
	cd ..
	
        EchoTextLines \
          "The nvram-wakeup address detection is finished now.\n"\
	  "If everything went well, you will find the detected nvram-wakeup\n"\
	  "settings in the file ~/guess-directisa/nvram-wakeup.conf. This file\n"\
	  "has been generated using the 'directisa' access method.\n" 
	[ -c /dev/nvram ] && EchoTextLines \
	  "In the directory ~/guess-nvram-module you will find the results using\n"\
	  "the 'nvram-kernel-module' access method. It's up to you to decide,\n"\
	  "what access method worked.\n"
	EchoTextLines \
	  "Check the files nvram-wakeup.conf and guess-error.log to see if\n"\
	  "everything went well. In order to use the generated conf file, you\n"\
	  "have to pass it as a command line parameter with the option -C to\n"\
	  "nvram-wakeup. Before doing this, you should copy it to /etc.\n"\
          "If the settings in your nvram-wakup.conf seem to work, please send\n"\
	  "this file to:\n"
        echo
        echo "Sergei.Haller@math.uni-giessen.de"
        echo
        $echo "By doing so, you are helping to keep nvram-wakeup support more boards."
      fi
    fi
  fi
fi
